==> readmore_extrafield-3.0.3.tar.gz: readmore_extrafield/src/Plugin/ExtraField/Display/ReadmoreExtrafield.php <==
<?php

namespace Drupal\readmore_extrafield\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use Drupal\Core\Url;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Form\FormStateInterface;

/**
 * Readmore Extra field display using extra_field + extra_field_plus.
 *
 * @ExtraFieldDisplay(
 *   id = "readmore_extrafield",
 *   label = @Translation("Read more"),
 *   description = @Translation("Link to the entity"),
 *   bundles = {
 *     "node.*"
 *   },
 *   weight = 100
 * )
 */
class ReadmoreExtrafield extends ExtraFieldPlusDisplayFormattedBase {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity) {
    $settings = $this->getSettings();

    // Token support:
    $token = FALSE;
    if (\Drupal::moduleHandler()->moduleExists('token')) {
      /** @var \Drupal\Core\Utility\Token $token */
      $token = \Drupal::service('token');
    }

    // Link label:
    $link_title = !empty($settings['link_title']) ? $settings['link_title'] : $this->t('Read more');
    if ($token) {
      $link_title = $token->replace($link_title, [$entity->getEntityTypeId() => $entity], ['clear' => TRUE]);
    }

    $element = [
      '#theme' => 'readmore_extrafield',
      '#title' => $link_title,
      '#url' => Url::fromRoute('entity.node.canonical', [
        'node' => $entity->id(),
      ]),
      '#attributes' => [
        'class' => ['readmore-extrafield-link'],
      ],
      // Provide information about host entity and view_mode:
      '#entity' => $entity,
      '#view_mode' => $this->getViewMode(),
    ];

    // Additional classes:
    if (!empty($settings['link_classes'])) {
      $classesArray = explode(' ', $settings['link_classes']);
      foreach ($classesArray as $class) {
        if ($token) {
          $class = $token->replace($class, [$entity->getEntityTypeId() => $entity], ['clear' => TRUE]);
        }
        $element['#attributes']['class'][] = $class;
      }
    }

    if (!empty($settings['link_attr_title'])) {
      $linkAttrTitle = $settings['link_attr_title'];
      if ($token) {
        $linkAttrTitle = $token->replace($linkAttrTitle, [$entity->getEntityTypeId() => $entity], ['clear' => TRUE]);
      }
      $element['#attributes']['title'] = $linkAttrTitle;
    }

    if (!empty($settings['link_attr_rel'])) {
      $element['#attributes']['rel'] = $settings['link_attr_rel'];
    }

    if (!empty($settings['link_attr_target'])) {
      $element['#attributes']['target'] = $settings['link_attr_target'];
    }

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm() {
    $form = parent::settingsForm();

    $tokenSupport = \Drupal::moduleHandler()->moduleExists('token');
    $tokenSupportText = ($tokenSupport ? (' ' . t('You may use tokens.')) : '');

    $form['link_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#description' => $this->t('The label text of the read on hyperlink.'),
    ];
    $form['link_classes'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link classes'),
      '#description' => $this->t('Allows to set additional classes on the link, separated by space.') . $tokenSupportText,
    ];
    $form['link_attr_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link „title“ attribute'),
      '#description' => $this->t('Allows to set the „title“ attrribute value on the link.') . $tokenSupportText,
    ];
    $form['link_attr_rel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link „rel“ attribute'),
      '#description' => $this->t('Allows to set the „rel“ attrribute value on the link.'),
    ];
    $form['link_attr_target'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link „target“ attribute'),
      '#description' => $this->t('Allows to set the „target“ attrribute value on the link.'),
    ];

    if ($tokenSupport) {
      $form['token_help'] = [
        '#theme' => 'token_tree_link',
        // TODO - How can we get the entity type here?
        '#token_types' => [],
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultFormValues() {
    $values = parent::defaultFormValues();

    $values += [
      'link_title' => $this->t('Read more'),
      'link_classes' => '',
      'link_attr_title' => '',
      'link_attr_rel' => '',
      'link_attr_target' => '',
    ];

    return $values;
  }

  /**
   * @inheritDoc
   */
  protected function settingsSummary(FormStateInterface $form_state) {
    return [
      $this->t('Label: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_title'),
      ]),
      $this->t('Link classes: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_classes'),
      ]),
      $this->t('Link „title“ attribute: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_attr_title'),
      ]),
      $this->t('Link „rel“ attribute: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_attr_rel'),
      ]),
      $this->t('Link „target“ attribute: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_attr_target'),
      ]),
    ];
  }

}

==> readmore_extrafield-3.0.4.tar.gz: readmore_extrafield/src/Plugin/ExtraField/Display/ReadmoreExtrafield.php <==
<?php

namespace Drupal\readmore_extrafield\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use Drupal\Core\Url;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Form\FormStateInterface;

/**
 * Readmore Extra field display using extra_field + extra_field_plus.
 *
 * @ExtraFieldDisplay(
 *   id = "readmore_extrafield",
 *   label = @Translation("Read more"),
 *   description = @Translation("Link to the entity"),
 *   bundles = {
 *     "node.*"
 *   },
 *   weight = 100
 * )
 */
class ReadmoreExtrafield extends ExtraFieldPlusDisplayFormattedBase {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity) {
    $settings = $this->getSettings();

    // Token support:
    $token = FALSE;
    if (\Drupal::moduleHandler()->moduleExists('token')) {
      /** @var \Drupal\Core\Utility\Token $token */
      $token = \Drupal::service('token');
    }

    // Link label:
    $link_title = !empty($settings['link_title']) ? $settings['link_title'] : $this->t('Read more');
    if ($token) {
      $link_title = $token->replace($link_title, [$entity->getEntityTypeId() => $entity], ['clear' => TRUE]);
    }

    $element = [
      '#theme' => 'readmore_extrafield',
      '#title' => $link_title,
      '#url' => Url::fromRoute('entity.node.canonical', [
        'node' => $entity->id(),
      ]),
      '#attributes' => [
        'class' => ['readmore-extrafield-link'],
      ],
      // Provide information about host entity and view_mode:
      '#entity' => $entity,
      '#view_mode' => $this->getViewMode(),
    ];

    // Additional classes:
    if (!empty($settings['link_classes'])) {
      $classesArray = explode(' ', $settings['link_classes']);
      foreach ($classesArray as $class) {
        if ($token) {
          $class = $token->replace($class, [$entity->getEntityTypeId() => $entity], ['clear' => TRUE]);
        }
        $element['#attributes']['class'][] = $class;
      }
    }

    if (!empty($settings['link_attr_title'])) {
      $linkAttrTitle = $settings['link_attr_title'];
      if ($token) {
        $linkAttrTitle = $token->replace($linkAttrTitle, [$entity->getEntityTypeId() => $entity], ['clear' => TRUE]);
      }
      $element['#attributes']['title'] = $linkAttrTitle;
    }

    if (!empty($settings['link_attr_rel'])) {
      $element['#attributes']['rel'] = $settings['link_attr_rel'];
    }

    if (!empty($settings['link_attr_target'])) {
      $element['#attributes']['target'] = $settings['link_attr_target'];
    }

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm() {
    $form = parent::settingsForm();

    $tokenSupport = \Drupal::moduleHandler()->moduleExists('token');
    $tokenSupportText = ($tokenSupport ? (' ' . $this->t('You may use tokens.')) : '');

    $form['link_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#description' => $this->t('The label text of the read on hyperlink.'),
    ];
    $form['link_classes'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link classes'),
      '#description' => $this->t('Allows to set additional classes on the link, separated by space.') . $tokenSupportText,
    ];
    $form['link_attr_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link „title“ attribute'),
      '#description' => $this->t('Allows to set the „title“ attrribute value on the link.') . $tokenSupportText,
    ];
    $form['link_attr_rel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link „rel“ attribute'),
      '#description' => $this->t('Allows to set the „rel“ attrribute value on the link.'),
    ];
    $form['link_attr_target'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link „target“ attribute'),
      '#description' => $this->t('Allows to set the „target“ attrribute value on the link.'),
    ];

    if ($tokenSupport) {
      $form['token_help'] = [
        '#theme' => 'token_tree_link',
        // @todo How can we get the entity type here?
        '#token_types' => [],
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultFormValues() {
    $values = parent::defaultFormValues();

    $values += [
      'link_title' => $this->t('Read more'),
      'link_classes' => '',
      'link_attr_title' => '',
      'link_attr_rel' => '',
      'link_attr_target' => '',
    ];

    return $values;
  }

  /**
   * {@inheritdoc}
   */
  protected function settingsSummary(FormStateInterface $form_state) {
    return [
      $this->t('Label: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_title'),
      ]),
      $this->t('Link classes: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_classes'),
      ]),
      $this->t('Link „title“ attribute: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_attr_title'),
      ]),
      $this->t('Link „rel“ attribute: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_attr_rel'),
      ]),
      $this->t('Link „target“ attribute: @value', [
        '@value' => $this->getSummarySetting($form_state, 'link_attr_target'),
      ]),
    ];
  }

}
